searchData={"items":[{"type":"task","title":"mix tz.download","doc":"","ref":"Mix.Tasks.Tz.Download.html"},{"type":"function","title":"Mix.Tasks.Tz.Download.run/1","doc":"","ref":"Mix.Tasks.Tz.Download.html#run/1"},{"type":"module","title":"Tz","doc":"","ref":"Tz.html"},{"type":"function","title":"Tz.iana_version/0","doc":"Returns the IANA time zone database version.","ref":"Tz.html#iana_version/0"},{"type":"module","title":"Tz.HTTP","doc":"","ref":"Tz.HTTP.html"},{"type":"function","title":"Tz.HTTP.get_http_client!/0","doc":"Return the http client module configured for tz.","ref":"Tz.HTTP.html#get_http_client!/0"},{"type":"behaviour","title":"Tz.HTTP.HTTPClient","doc":"A behaviour allowing to plug in any HTTP client.","ref":"Tz.HTTP.HTTPClient.html"},{"type":"callback","title":"Tz.HTTP.HTTPClient.request/2","doc":"","ref":"Tz.HTTP.HTTPClient.html#c:request/2"},{"type":"module","title":"Tz.UpdatePeriodically","doc":"A process enabling automatic IANA data updates periodically.","ref":"Tz.UpdatePeriodically.html"},{"type":"function","title":"Tz.UpdatePeriodically.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Tz.UpdatePeriodically.html#child_spec/1"},{"type":"module","title":"Tz.Updater","doc":"","ref":"Tz.Updater.html"},{"type":"function","title":"Tz.Updater.maybe_recompile/0","doc":"Recompiles the period maps only if more recent IANA data is available.","ref":"Tz.Updater.html#maybe_recompile/0"},{"type":"module","title":"Tz.WatchPeriodically","doc":"A process watching for IANA data updates periodically.","ref":"Tz.WatchPeriodically.html"},{"type":"function","title":"Tz.WatchPeriodically.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Tz.WatchPeriodically.html#child_spec/1"},{"type":"extras","title":"Tz","doc":"# Tz\n\nTime zone support for Elixir.\n\nThe Elixir standard library does not ship with a time zone database. As a result, the functions in the `DateTime`\nmodule can, by default, only operate on datetimes in the UTC time zone. Alternatively (and\n[deliberately](https://elixirforum.com/t/14743)), the standard library relies on\nthird-party libraries, such as `tz`, to bring in time zone support and deal with datetimes in other time zones than UTC.\n\nThe `tz` library relies on the [time zone database](https://data.iana.org/time-zones/tzdb/) maintained by\n[IANA](https://www.iana.org). As of version 0.27.1, `tz` uses version **tzdata2024a** of the IANA time zone database.\n\n* [Installation and usage](#installation-and-usage)\n* [Core principles](#core-principles)\n* [Automatic updates](#automatic-time-zone-data-updates)\n* [Manual updates](#manual-time-zone-data-updates)\n* [Automatic vs manual updates](#automatic-vs-manual-updates)\n* [Disable updates in test env](#disable-updates-in-test-environment)\n* [Default HTTP client](#default-http-client)\n* [Custom HTTP client](#custom-http-client)\n* [Performance tweaks](#performance-tweaks)\n* [Custom storage location](#custom-storage-location-of-time-zone-data)\n* [Get the IANA version](#get-the-iana-time-zone-database-version)\n* [Time zone utility functions](#time-zone-utility-functions)\n* [Other libraries](#other-time-zone-database-implementations)\n* [Acknowledgments](#acknowledgments)","ref":"readme.html"},{"type":"extras","title":"Installation and usage - Tz","doc":"Add `tz` for Elixir as a dependency in your `mix.exs` file:\n\n```elixir\ndef deps do\n  [\n    {:tz, \"~> 0.27\"}\n  ]\nend\n```\n\nTo use the `tz` database, either configure it via configuration:\n```elixir\nconfig :elixir, :time_zone_database, Tz.TimeZoneDatabase\n```\n\nor by calling `Calendar.put_time_zone_database/1`:\n```elixir\nCalendar.put_time_zone_database(Tz.TimeZoneDatabase)\n```\n\nor by passing the module name `Tz.TimeZoneDatabase` directly to the functions that need a time zone database:\n```elixir\nDateTime.now(\"America/Sao_Paulo\", Tz.TimeZoneDatabase)\n```\n\nRefer to the [DateTime API](https://hexdocs.pm/elixir/DateTime.html) for more details\nabout handling datetimes with time zones.","ref":"readme.html#installation-and-usage"},{"type":"extras","title":"Core principles - Tz","doc":"","ref":"readme.html#core-principles"},{"type":"extras","title":"Battle-tested - Tz","doc":"The `tz` library is tested against nearly 10 million past dates, which includes most of all possible edge cases.\n\nThe repo [tzdb_test](https://github.com/mathieuprog/tzdb_test) compares the output of the different available libraries (tz, time_zone_info, tzdata and zoneinfo), and gives some idea of the difference in performance.","ref":"readme.html#battle-tested"},{"type":"extras","title":"Pre-compiled time zone data - Tz","doc":"Time zone periods are deducted from the [IANA time zone data](https://data.iana.org/time-zones/tzdb/). A period is a\nperiod of time where a certain offset is observed. For example, in Belgium from 31 March 2019 until 27 October 2019, clock\nwent forward by 1 hour; as Belgium has a base offset from UTC of 1 hour, this means that during this period, Belgium observed a total offset of 2 hours from UTC time (base UTC offset of 1 hour + DST offset of 1 hour).\n\nThe time zone periods are computed and made available in Elixir maps during compilation time, to be consumed by the\n[DateTime](https://hexdocs.pm/elixir/DateTime.html#module-time-zone-database) module.","ref":"readme.html#pre-compiled-time-zone-data"},{"type":"extras","title":"Automatic time zone data updates - Tz","doc":"`tz` can watch for IANA time zone database updates and automatically recompile the time zone periods.\n\nTo enable automatic updates, add `Tz.UpdatePeriodically` as a child in your supervisor:\n\n```elixir\n{Tz.UpdatePeriodically, []}\n```\n\nYou may pass the option `:interval_in_days` in order to configure the frequency of the updates:\n\n```elixir\n{Tz.UpdatePeriodically, [interval_in_days: 5]}\n```","ref":"readme.html#automatic-time-zone-data-updates"},{"type":"extras","title":"Manual time zone data updates - Tz","doc":"If you do not wish to update automatically, but still wish to be alerted for new upcoming IANA updates, add\n`Tz.WatchPeriodically` as a child in your supervisor:\n\n```elixir\n{Tz.WatchPeriodically, []}\n```\n\n`Tz.WatchPeriodically` simply logs to your server when a new time zone database is available.\n\nYou may pass the options:\n* `:interval_in_days`: frequency of the checks\n* `:on_update`: a user callback executed when an update is available\n\nFor updating IANA data manually, there are 2 options:\n\n* just update the `tz` library in the `mix.exs` file, which hopefully includes the latest IANA time zone database (if not, wait for the library maintainer to include the latest version or send a pull request on GitHub).\n\n* download the files and recompile:\n\n  1. Configure a custom directory with the `:data_dir` option. For example:\n     ```elixir\n     config :tz, :data_dir, Path.join(Path.dirname(__DIR__), \"priv\")\n     ```\n  2. Download the files manually by running the mix task below:\n     ```bash\n     mix tz.download\n     ```\n  3. Recompile the dependency:\n     ```bash\n     mix deps.compile tz --force\n     ```\n     Or from an iex session to recompile at runtime:\n     ```bash\n     iex -S mix\n     iex> Tz.Compiler.compile()\n     ```\n     Note that recompilation at runtime is not persistent, run `mix deps.compile tz --force` in addition.\n  4. Check that the version is the one expected:\n     ```bash\n     iex> Tz.iana_version()\n     ```\n\nTo force a specific IANA version:\n\n  1. Configure a custom directory with the `:data_dir` option. For example:\n     ```elixir\n     config :tz, :data_dir, Path.join(Path.dirname(__DIR__), \"priv\")\n     ```\n  2. Download the files by running the mix task below (say we want the 2021a version):\n     ```bash\n     mix tz.download 2021a\n     ```\n  3. Add the `:iana_version` option:\n     ```elixir\n     config :tz, :iana_version, \"2021a\"\n     ```\n  4. Recompile the dependency:\n     ```bash\n     mix deps.compile tz --force\n     ```\n  5. Check that the version is the one expected:\n     ```bash\n     iex> Tz.iana_version()\n     ```","ref":"readme.html#manual-time-zone-data-updates"},{"type":"extras","title":"Automatic vs manual updates - Tz","doc":"Some users prefer to use `Tz.WatchPeriodically` (over `Tz.UpdatePeriodically`) to watch and update manually. Example cases:\n\n* Memory-limited systems: small containers or embedded devices may not afford to recompile the time zone data at runtime.\n* Restricted environments: the request may be blocked because of security policies.\n* Security concerns: some users may prefer to analyze the files coming from external sources (`https://data.iana.org` in this case) before processing.\n* Systems interoperability: a user may use some other systems using an older version of the IANA database, and  so the user may want to keep a lower version of the IANA data with `tz` to ensure IANA versions match.","ref":"readme.html#automatic-vs-manual-updates"},{"type":"extras","title":"Disable updates in test environment - Tz","doc":"To avoid the updater to run while executing tests, you may conditionally add the child worker in your supervisor. For example:\n\n```elixir\nchildren = [\n  MyApp.Repo,\n  MyApp.Endpoint,\n  #...\n]\n|> append_if(Application.get_env(:my_app, :env) != :test, {Tz.UpdatePeriodically, []})\n```\n\n```elixir\ndefp append_if(list, condition, item) do\n  if condition, do: list ++ [item], else: list\nend\n```\n\nIn `config.exs`, add `config :my_app, env: Mix.env()`.","ref":"readme.html#disable-updates-in-test-environment"},{"type":"extras","title":"Default HTTP client - Tz","doc":"Lastly, add the http client `mint` and ssl certificate store `castore` into your `mix.exs` file:\n\n```elixir\ndefp deps do\n  [\n    {:castore, \"~> 1.0\"},\n    {:mint, \"~> 1.6\"},\n    {:tz, \"~> 0.27\"}\n  ]\nend\n```\n\nYou may also add custom [options](https://hexdocs.pm/mint/Mint.HTTP.html#connect/4-options) for the http client `mint`:\n\n```elixir\nconfig :tz, Tz.HTTP.Mint.HTTPClient,\n  proxy: {:http, proxy_host, proxy_port, []}\n```","ref":"readme.html#default-http-client"},{"type":"extras","title":"Custom HTTP client - Tz","doc":"You may implement the `Tz.HTTP.HTTPClient` behaviour in order to use another HTTP client.\n\nExample using [Finch](https://github.com/keathley/finch):\n```elixir\ndefmodule MyApp.Tz.HTTPClient do\n  @behaviour Tz.HTTP.HTTPClient\n\n  alias Tz.HTTP.HTTPResponse\n  alias MyApp.MyFinch\n\n  @impl Tz.HTTP.HTTPClient\n  def request(hostname, path) do\n    {:ok, response} =\n      Finch.build(:get, \"https://\" <> Path.join(hostname, path))\n      |> Finch.request(MyFinch)\n\n    %HTTPResponse{\n      status_code: response.status,\n      body: response.body\n    }\n  end\nend\n```\n\nA `Tz.HTTP.HTTPResponse` struct must be returned with fields `:status_code` and `:body`.\n\nThe custom module must then be passed into the config:\n```elixir\nconfig :tz, :http_client, MyApp.Tz.HTTPClient\n```","ref":"readme.html#custom-http-client"},{"type":"extras","title":"Performance tweaks - Tz","doc":"`tz` accepts two environment options to tweak performance.","ref":"readme.html#performance-tweaks"},{"type":"extras","title":"Reducing period lookup time - Tz","doc":"For time zones that have ongoing DST changes, period lookups for dates far in the future result in periods being\ndynamically computed based on the IANA data. For example, what is the period for 20 March 2040 for New York (let's\nassume that the last rules for New York still mention an ongoing DST change as you read this)? We can't compile periods\nindefinitely in the future; by default, such periods are computed until 5 years from compilation time. Dynamic period\ncomputations is a slow operation.\n\nYou can decrease **period lookup time** for time zones affected by DST changes, by specifying until what year those periods have to be computed:\n\n```elixir\nconfig :tz, build_dst_periods_until_year: 20 + NaiveDateTime.utc_now().year\n```\n\nNote that increasing the year will also slightly increase compilation time, as it generates more periods to compile.\n\nThe default setting computes periods for a period of 5 years from the time the code is compiled. Note that if you have added the automatic updater, the periods will be recomputed with every update, which occurs multiple times throughout the year.","ref":"readme.html#reducing-period-lookup-time"},{"type":"extras","title":"Rejecting old time zone periods - Tz","doc":"You can slightly decrease **memory usage** and **compilation time**, by rejecting time zone periods before a given year:\n\n```elixir\nconfig :tz, reject_periods_before_year: 2010\n```\n\nNote that this option is aimed towards embedded devices as the difference should be insignificant for ordinary servers.\n\nBy default, no periods are rejected.","ref":"readme.html#rejecting-old-time-zone-periods"},{"type":"extras","title":"Custom storage location of time zone data - Tz","doc":"By default, the files are stored in the `priv` directory of the `tz` library. You may customize the directory that will hold all of the IANA timezone data. For example, if you want to store the files in your project's `priv` dir instead:\n\n```elixir\nconfig :tz, :data_dir, Path.join(Path.dirname(__DIR__), \"priv\")\n```","ref":"readme.html#custom-storage-location-of-time-zone-data"},{"type":"extras","title":"Get the IANA time zone database version - Tz","doc":"```elixir\nTz.iana_version() == \"2023c\"\n```","ref":"readme.html#get-the-iana-time-zone-database-version"},{"type":"extras","title":"Time zone utility functions - Tz","doc":"Tz's API is intentionally kept as minimal as possible to implement Calendar.TimeZoneDatabase's behaviour. Utility functions\naround time zones are provided by [TzExtra](https://github.com/mathieuprog/tz_extra).\n\n* [`TzExtra.countries_time_zones/1`](https://github.com/mathieuprog/tz_extra#tzextracountries_time_zones1): returns a list of time zone data by country\n* [`TzExtra.time_zone_identifiers/1`](https://github.com/mathieuprog/tz_extra#tzextratime_zone_identifiers1): returns a list of time zone identifiers\n* [`TzExtra.civil_time_zone_identifiers/1`](https://github.com/mathieuprog/tz_extra#tzextracivil_time_zone_identifiers1): returns a list of time zone identifiers that are tied to a country\n* [`TzExtra.countries/0`](https://github.com/mathieuprog/tz_extra#tzextracountries0): returns a list of ISO country codes with their English name\n* [`TzExtra.get_canonical_time_zone_identifier/1`](https://github.com/mathieuprog/tz_extra#tzextraget_canonical_time_zone_identifier1): returns the canonical time zone identifier for the given time zone identifier\n* [`TzExtra.Changeset.validate_time_zone_identifier/3`](https://github.com/mathieuprog/tz_extra#tzextraChangesetvalidate_time_zone_identifier3): an Ecto Changeset validator, validating that the user input is a valid time zone\n* [`TzExtra.Changeset.validate_civil_time_zone_identifier/3`](https://github.com/mathieuprog/tz_extra#tzextraChangesetvalidate_civil_time_zone_identifier3): an Ecto Changeset validator, validating that the user input is a valid civil time zone\n* [`TzExtra.Changeset.validate_iso_country_code/3`](https://github.com/mathieuprog/tz_extra#tzextraChangesetvalidate_iso_country_code3): an Ecto Changeset validator, validating that the user input is a valid ISO country code","ref":"readme.html#time-zone-utility-functions"},{"type":"extras","title":"Other time zone database implementations - Tz","doc":"","ref":"readme.html#other-time-zone-database-implementations"},{"type":"extras","title":"Based on IANA time zone data - Tz","doc":"* [time_zone_info](https://github.com/hrzndhrn/time_zone_info)\n* [tzdata](https://github.com/lau/tzdata) (not recommended due to bugs)","ref":"readme.html#based-on-iana-time-zone-data"},{"type":"extras","title":"Based on OS-supplied zoneinfo files - Tz","doc":"Recommended for embedded devices.\n\n* [zoneinfo](https://github.com/smartrent/zoneinfo)","ref":"readme.html#based-on-os-supplied-zoneinfo-files"},{"type":"extras","title":"Acknowledgments - Tz","doc":"The current state of Tz wouldn't have been possible to achieve without the work of the following contributors related to time zones:\n\n* contributors adding time zone support to Elixir ([call for proposal](https://elixirforum.com/t/14743), [initial proposal](https://github.com/elixir-lang/elixir/pull/7914), [final proposal](https://github.com/elixir-lang/elixir/pull/8383));\n* contributors to the [time_zone_info](https://github.com/hrzndhrn/time_zone_info) library, based on which Tz could compare its speed and drastically improve performance;\n* contributors to the Java `java.time` package, against which Tz is testing its output.","ref":"readme.html#acknowledgments"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}